@@ -33,10 +33,8 @@ class DIDClient(BaseClient):
         List all data identifiers in a scope which match a given pattern.
 
         :param scope: The scope name.
-        :param pattern: The wildcard pattern.
-        :param type:  The type of the did: all(container, dataset, file), collection(dataset or container), dataset, container
-        :param ignore_case: Ignore case distinctions.
-        :param session: The database session in use.
+        :param filters: A dictionary of key/value pairs like {'name': 'file_name','rse-expression': 'tier0'}.
+        :param type: The type of the did: 'all'(container, dataset or file)|'collection'(dataset or container)|'dataset'|'container'|'file'
         """
 
         path = '/'.join([self.DIDS_BASEURL, scope, 'dids', 'search'])
@@ -88,7 +86,7 @@ class DIDClient(BaseClient):
 
     def add_dids(self, dids):
         """
-        Buld add datasets/containers.
+        Bulk add datasets/containers.
         """
         path = '/'.join([self.DIDS_BASEURL])
         url = build_url(choice(self.list_hosts), path=path)
@@ -185,6 +183,9 @@ class DIDClient(BaseClient):
         Add dids to dids.
 
         :param attachments: The attachments.
+            attachments is: [attachment, attachment, ...]
+            attachment is: {'scope': scope, 'name': name, 'dids': dids}
+            dids is: [{'scope': scope, 'name': name}, ...]
         """
         path = '/'.join([self.DIDS_BASEURL, 'attachments'])
         url = build_url(choice(self.list_hosts), path=path)
@@ -200,6 +201,9 @@ class DIDClient(BaseClient):
         Add files to datasets.
 
         :param attachments: The attachments.
+            attachments is: [attachment, attachment, ...]
+            attachment is: {'scope': scope, 'name': name, 'dids': dids}
+            dids is: [{'scope': scope, 'name': name}, ...]
         """
         return self.attach_dids_to_dids(attachments=attachments)
 
@@ -208,6 +212,9 @@ class DIDClient(BaseClient):
         Add datasets_to_containers.
 
         :param attachments: The attachments.
+            attachments is: [attachment, attachment, ...]
+            attachment is: {'scope': scope, 'name': name, 'dids': dids}
+            dids is: [{'scope': scope, 'name': name}, ...]
         """
         return self.attach_dids_to_dids(attachments=attachments)
 
@@ -216,6 +223,9 @@ class DIDClient(BaseClient):
         Add containers_to_containers.
 
         :param attachments: The attachments.
+            attachments is: [attachment, attachment, ...]
+            attachment is: {'scope': scope, 'name': name, 'dids': dids}
+            dids is: [{'scope': scope, 'name': name}, ...]
         """
         return self.attach_dids_to_dids(attachments=attachments)
 
@@ -444,3 +454,19 @@ class DIDClient(BaseClient):
         else:
             exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
             raise exc_cls(exc_msg)
+
+    def get_dataset_by_guid(self, guid):
+        """
+        Get the parent datasets for a given GUID.
+       :param guid: The GUID.
+
+        :returns: A did
+        """
+        path = '/'.join([self.DIDS_BASEURL, guid, 'guid'])
+        url = build_url(choice(self.list_hosts), path=path)
+        r = self._send_request(url, type='GET')
+        if r.status_code == codes.ok:
+            return self._load_json_data(r)
+        else:
+            exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
+            raise exc_cls(exc_msg)
