@@ -25,7 +25,7 @@ class LockClient(BaseClient):
 
     def get_dataset_locks(self, scope, name):
         """
-        Sends the request to get information about a given account.
+        Get a dataset locks of the specified dataset.
 
         :param scope: the scope of the did of the locks to list.
         :param name: the name of the did of the locks to list.
@@ -39,12 +39,12 @@ class LockClient(BaseClient):
             locks = self._load_json_data(r)
             return locks
         else:
-            exc_cls, exc_msg = self._get_exception(r.headers)
+            exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
             raise exc_cls(exc_msg)
 
     def get_dataset_locks_by_rse(self, rse):
         """
-        Sends the request to get information about a given account.
+        Get all dataset locks of the specified rse.
 
         :param rse: the rse of the locks to list.
         """
@@ -57,6 +57,6 @@ class LockClient(BaseClient):
             locks = self._load_json_data(r)
             return locks
         else:
-            exc_cls, exc_msg = self._get_exception(r.headers)
+            exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
 
             raise exc_cls(exc_msg)
