@@ -49,17 +49,17 @@ class UseCaseDefinition(UCEmulator):
     def setup(self, ctx):
         d = date.today()
         ctx.runnumber = long('%02d%02d%02d00' % (d.year - 2000, d.month, d.day))
-        used_runnnumbers = Client(account='tier0').list_values('run_number')
+        used_runnnumbers = Client(account='tzero').list_values('run_number')
         while unicode(ctx.runnumber) in used_runnnumbers:
             ctx.runnumber += 1
         print '== TZero: starts with runnumber offset: %s' % ctx.runnumber
 
     @UCEmulator.UseCase
     def EMULATION_RUN(self, interval, filescale, dataXX, runnumber, runspertag, calibfraction, timespan):
-        tz_account = 'tier0'
-        tz_group = 'tier0'
+        tz_account = 'tzero'
+        tz_group = 'tzero'
         tz_provenance = 'T0'
-        tz_rse = 'MOCK3'
+        tz_rse = 'CERN-PROD_TZERO'
         tz_filesize = 2000000000     # 2GB
 
         runnumber = random.randrange(400000, 500000)
@@ -259,9 +259,9 @@ class UseCaseDefinition(UCEmulator):
                                     'statuses': {'monotonic': True}, 'meta': meta,
                                     'rules': [{'account': tz_account, 'copies': 1,
                                                'rse_expression': tz_rse, 'grouping': 'DATASET'}]})  # The missing lifetime attribute indicated an infinite lifetime
-                with monitor.record_timer_block(['tzero.add_datasets', ('tzero.add_datasets.normalized', len(open_ds))]):
+                with monitor.record_timer_block(['emulator.tzero.client.add_datasets', ('emulator.tzero.client.add_datasets.normalized', len(open_ds))]):
                     client.add_datasets(open_ds)
-                monitor.record_counter('tzero.datasets', len(open_ds))
+                monitor.record_counter('emulator.tzero.client.datasets', len(open_ds))
                 # dids = [{'scope': d['scope'], 'name': d['name']} for d in open_ds]
                 # with monitor.record_timer_block(['tzero.add_replication_rule', ('tzero.add_replication_rule.normalized', len(open_ds))]):
                 #    client.add_replication_rule(dids, copies=1, rse_expression=tz_rse,
@@ -297,27 +297,29 @@ class UseCaseDefinition(UCEmulator):
                         # filename = datasetname + '._' + str(i).zfill(6)
                         # TODO: fix when meta-data is working properly
                         filename = datasetname + '._' + uuid()
-                        onefile = {'name': filename, 'scope': scope, 'bytes': tz_filesize}
+                        onefile = {'name': filename, 'scope': scope, 'bytes': tz_filesize, 'pfn': 'mock://srm-atlas.cern.ch:8443/castor/cern.ch/grid/atlas/tzero/this/is/from/the/emulation/%s' % filename}
                         no_files += 1
                         newfiles.append(onefile)
                     d[3] = target
                     # with monitor.record_timer_block(['panda.attach_dids_to_dids', ('panda.attach_dids_to_dids.normalized_datasets', len(inserts)), ('panda.attach_dids_to_dids.normalized_files', no_files)]):
                     #   client.attach_dids_to_dids(attachments=inserts)
-                    with monitor.record_timer_block(['tzero.add_files_to_dataset', ('tzero.add_files_to_dataset.normalized', len(newfiles))]):
-                        try:
-                            client.add_files_to_dataset(scope=scope, name=datasetname, files=newfiles, rse=tz_rse)
-                        except Exception, e:
-                            print traceback.format_exc()
-                    monitor.record_counter('tzero.files', len(newfiles))
+                    monitor.record_counter('emulator.tzero.client.files', len(newfiles))
+                    while len(newfiles):
+                        with monitor.record_timer_block(['emulator.tzero.client.add_files_to_dataset', ('emulator.tzero.client.add_files_to_dataset.normalized', len(newfiles))]):
+                            try:
+                                client.add_files_to_dataset(scope=scope, name=datasetname, files=newfiles[:500], rse=tz_rse)
+                                del newfiles[:500]
+                            except Exception, e:
+                                print traceback.format_exc()
             delta = time.time() - now
             print '== TZero: Appending %s files to %s datasets took %s seconds' % (no_files, len(ds), delta)
-            monitor.record_timer('tzero.registering_all_replicas', delta * 1000)
-            monitor.record_timer('tzero.registering_all_replicas.normalized', (delta * 1000) / no_files)
+            monitor.record_timer('emulator.tzero.registering_all_replicas', delta * 1000)
+            monitor.record_timer('emulator.tzero.registering_all_replicas.normalized', (delta * 1000) / no_files)
 
         # close all datasets
         for scope, datasetname, s, c in ds:
             print '== TZero: Close dataset %s:%s' % (scope, datasetname)
-            with monitor.record_timer_block('tzero.close'):
+            with monitor.record_timer_block('emulator.tzero.client.close'):
                 try:
                     client.close(scope=scope, name=datasetname)
                 except Exception, e:
