@@ -7,6 +7,7 @@
 # Authors:
 # - Vincent Garonne, <vincent.garonne@cern.ch>, 2012-2013
 # - Thomas Beermann, <thomas.beermann@cern.ch>, 2012
+# - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
 
 from getpass import getuser
 from os import remove
@@ -16,12 +17,16 @@ from nose.tools import raises
 
 from rucio.client.baseclient import BaseClient
 from rucio.client.client import Client
+from rucio.common.config import config_get
 from rucio.common.exception import CannotAuthenticate, ClientProtocolNotSupported
 
 
 class TestBaseClient():
 
     def setup(self):
+        self.cacert = config_get('test', 'cacert')
+        self.usercert = config_get('test', 'usercert')
+
         try:
             remove('/tmp/' + getuser() + '/.rucio_root/auth_token_root')
         except OSError, e:
@@ -34,13 +39,13 @@ class TestBaseClient():
     def testUserpass(self):
         """ CLIENTS (BASECLIENT): authenticate with userpass."""
         creds = {'username': 'ddmlab', 'password': 'secret'}
-        BaseClient(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='userpass', creds=creds)
+        BaseClient(account='root', ca_cert=self.cacert, auth_type='userpass', creds=creds)
 
     @raises(CannotAuthenticate)
     def testUserpassWrongCreds(self):
         """ CLIENTS (BASECLIENT): try to authenticate with wrong username."""
         creds = {'username': 'wrong', 'password': 'secret'}
-        BaseClient(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='userpass', creds=creds)
+        BaseClient(account='root', ca_cert=self.cacert, auth_type='userpass', creds=creds)
 
     @raises(CannotAuthenticate)
     def testUserpassNoCACert(self):
@@ -50,20 +55,14 @@ class TestBaseClient():
 
     def testx509(self):
         """ CLIENTS (BASECLIENT): authenticate with x509."""
-        creds = {'client_cert': '/opt/rucio/etc/web/usercert.pem'}
-        BaseClient(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='x509', creds=creds)
-
-    @raises(CannotAuthenticate)
-    def testx509WrongCert(self):
-        """ CLIENTS (BASECLIENT): try authenticate with userpass and wrong certificate."""
-        creds = {'client_cert': '/opt/rucio/etc/web/ca.crt'}
-        BaseClient(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='x509', creds=creds)
+        creds = {'client_cert': self.usercert}
+        BaseClient(account='root', ca_cert=self.cacert, auth_type='x509', creds=creds)
 
     @raises(CannotAuthenticate)
     def testx509NonExistingCert(self):
         """ CLIENTS (BASECLIENT): authenticate with x509 with missing certificate."""
         creds = {'client_cert': '/opt/rucio/etc/web/notthere.crt'}
-        BaseClient(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='x509', creds=creds)
+        BaseClient(account='root', ca_cert=self.cacert, auth_type='x509', creds=creds)
 
     @raises(ClientProtocolNotSupported)
     def testClientProtocolNotSupported(self):
@@ -75,12 +74,13 @@ class TestBaseClient():
 class TestRucioClients():
 
     def setup(self):
+        self.cacert = config_get('test', 'cacert')
         self.marker = '$> '
 
     def test_ping(self):
         """ PING (CLIENT): Ping Rucio """
         creds = {'username': 'ddmlab', 'password': 'secret'}
 
-        c = Client(account='root', ca_cert='/opt/rucio/etc/web/ca.crt', auth_type='userpass', creds=creds)
+        c = Client(account='root', ca_cert=self.cacert, auth_type='userpass', creds=creds)
 
         print c.ping()
