@@ -243,6 +243,8 @@ class TestDIDClients:
         nb_datasets = 5
         nb_files = 5
         attachments, dsns = list(), list()
+        guid_to_query = None
+        dsn = {}
         for i in xrange(nb_datasets):
             attachment = {}
             attachment['scope'] = tmp_scope
@@ -254,11 +256,16 @@ class TestDIDClients:
                               'bytes': 724963570L, 'adler32': '0cc737eb',
                               'meta': {'guid': str(generate_uuid()), 'events': 100}})
             attachment['dids'] = files
-            dsns.append({'scope': tmp_scope, 'name': attachment['name']})
+            guid_to_query = files[0]['meta']['guid']
+            dsn = {'scope': tmp_scope, 'name': attachment['name']}
+            dsns.append(dsn)
             attachments.append(attachment)
 
         self.did_client.add_datasets(dsns=dsns)
         self.did_client.attach_dids_to_dids(attachments=attachments)
+        l = [i for i in self.did_client.get_dataset_by_guid(guid_to_query)]
+
+        assert_equal([dsn], l)
 
         cnt_name = 'cnt_%s' % generate_uuid()
         self.did_client.add_container(scope='mock', name=cnt_name)
@@ -536,7 +543,7 @@ class TestDIDClients:
         content = self.did_client.list_files(scope, files1[i]['name'])
         assert_true(content is not None)
         for d in content:
-            assert_true(d == files1[i])
+            assert_true(d['name'] == files1[i]['name'])
 
         # List container content
         for d in [{'name': x['name'], 'scope': x['scope'], 'bytes': x['bytes'], 'adler32': x['adler32']} for x in self.did_client.list_files(scope, container)]:
@@ -613,3 +620,39 @@ class TestDIDClients:
         # Add files to dataset
         files = [{'scope': tmp_scope, 'name': tmp_file, 'bytes': 1L, 'adler32': '0cc737eb'}, ]
         self.did_client.attach_dids(scope=tmp_scope, name=tmp_dataset, dids=files)
+
+    @raises
+    def test_open(self):
+        """ DATA IDENTIFIERS (CLIENT): test to re-open data identifiers for priv account"""
+
+        tmp_rse = 'MOCK'
+        tmp_scope = 'mock'
+
+        # Add dataset
+        tmp_dataset = 'dsn_%s' % generate_uuid()
+
+        # Add file replica
+        tmp_file = 'file_%s' % generate_uuid()
+        self.replica_client.add_replica(rse=tmp_rse, scope=tmp_scope, name=tmp_file, bytes=1L, adler32='0cc737eb')
+
+        # Add dataset
+        self.did_client.add_dataset(scope=tmp_scope, name=tmp_dataset)
+
+        # Add files to dataset
+        files = [{'scope': tmp_scope, 'name': tmp_file, 'bytes': 1L, 'adler32': '0cc737eb'}, ]
+        self.did_client.add_files_to_dataset(scope=tmp_scope, name=tmp_dataset, files=files)
+
+        # Add a second file replica
+        tmp_file = 'file_%s' % generate_uuid()
+        self.replica_client.add_replica(tmp_rse, tmp_scope, tmp_file, 1L, '0cc737eb')
+        # Add files to dataset
+        files = [{'scope': tmp_scope, 'name': tmp_file, 'bytes': 1L, 'adler32': '0cc737eb'}, ]
+        self.did_client.add_files_to_dataset(scope=tmp_scope, name=tmp_dataset, files=files)
+
+        # Close dataset
+        with assert_raises(UnsupportedStatus):
+            self.did_client.set_status(scope=tmp_scope, name=tmp_dataset, close=False)
+        self.did_client.set_status(scope=tmp_scope, name=tmp_dataset, open=False)
+
+        # Add a third file replica
+        self.did_client.set_status(scope=tmp_scope, name=tmp_dataset, open=True)
