@@ -15,15 +15,15 @@
 function RucioClient(token, account) {
     this.token = token;
     this.account = account;
-    this.url = 'https://rucio-lb-prod.cern.ch:443';
-    this.dumps = '//rucio-hadoop.cern.ch/dumps';
+    this.url = 'https://rucio-ui.cern.ch:443/proxy';
+    this.dumps = 'https://rucio-ui.cern.ch:443/dumpsproxy';
 };
 
 /* --- utility function --- */
 
 parse_json_stream = function(data) {
     var split_data = data.split('\n');
-    var ret_data = []
+    var ret_data = [];
     for (var i = 0; i < split_data.length; i++) {
         if (split_data[i].length <= 0) {
             break;
@@ -59,11 +59,11 @@ RucioClient.prototype.list_scopes = function(options) {
                            'X-Rucio-Account': this.account },
                  success: function(data)
                  {
-                     options.success(data)
+                     options.success(data);
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -81,7 +81,7 @@ RucioClient.prototype.list_identities = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -103,7 +103,7 @@ RucioClient.prototype.scope_list = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -144,7 +144,7 @@ RucioClient.prototype.list_replication_rules = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -165,19 +165,34 @@ RucioClient.prototype.list_subscription_rules_state = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
 
-
+/* list all subscriptions from dumps */
+RucioClient.prototype.list_subscription_rules_state_from_dumps = function(options) {
+    var url = this.dumps + '/subscription_states/' + options.date + '/' + options.hour + options.minutes + '.lst';
+    jQuery.ajax({url: url,
+                 async: false,
+                 crossDomain: true,
+                 success: function(data)
+                 {
+                     options.success(data);
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+                });
+};
 
 /* Create a new rule for an account */
 RucioClient.prototype.create_rule = function(options) {
     var url = this.url + '/rules/';
-    if (options.weight == '') { options.weight = null };
-    if (options.lifetime == '') { options.lifetime = null };
-    if (options.source_replica_expression == '') { options.source_replica_expression = null };
+    if (options.weight == '') { options.weight = null; };
+    if (options.lifetime == '') { options.lifetime = null; };
+    if (options.source_replica_expression == '') { options.source_replica_expression = null; };
     jQuery.ajax({url: url,
                  crossDomain: true,
                  type: 'POST',
@@ -198,7 +213,7 @@ RucioClient.prototype.create_rule = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -217,12 +232,11 @@ RucioClient.prototype.list_replication_rules = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
 
-
 /* list all RSEs in the system */
 RucioClient.prototype.list_rses = function(options) {
     var url = this.url + '/rses/';
@@ -240,12 +254,11 @@ RucioClient.prototype.list_rses = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
 
-
 /* get current space usage for RSE */
 RucioClient.prototype.get_rse_usage = function(options) {
     var url = this.url + '/rses/' + options.rse + '/usage';
@@ -260,7 +273,7 @@ RucioClient.prototype.get_rse_usage = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -279,7 +292,7 @@ RucioClient.prototype.list_rse_usage_history = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
                 });
 };
@@ -295,12 +308,11 @@ RucioClient.prototype.list_rse_usage_history_from_dumps = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
                 });
 };
 
-
 /* list all lock states per RSE from dumps */
 RucioClient.prototype.get_rse_lock_states_from_dumps = function(options) {
     var url = this.dumps + '/rse_locks/' + options.date + '/' + options.hour + '.lst';
@@ -313,13 +325,12 @@ RucioClient.prototype.get_rse_lock_states_from_dumps = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
                 });
 };
 
-
-/* show DID */
+/* show DID metadata */
 RucioClient.prototype.did_get_metadata = function(options) {
     var url = this.url + '/dids/' + options.scope + '/' + options.name + '/meta';
     jQuery.ajax({url: url,
@@ -333,7 +344,51 @@ RucioClient.prototype.did_get_metadata = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
+/* show DID files */
+RucioClient.prototype.did_get_files = function(options) {
+    var url = this.url + '/dids/' + options.scope + '/' + options.name + '/files';
+    jQuery.ajax({url: url,
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'text',
+                 success: function(data)
+                 {
+                     options.success(parse_json_stream(data));
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
+/* show DID replicas*/
+RucioClient.prototype.list_replicas = function(options) {
+    var url = this.url + '/replicas/list/';
+    if (options.async == null) {
+        options.async = true;
+    }
+    jQuery.ajax({url: url,
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'text',
+                 type: 'POST',
+                 data: JSON.stringify({'dids': [{'scope': options.scope, 'name': options.name}], 'unavailable': true, 'all_states': true }),
+                 async: options.async,
+                 success: function(data)
+                 {
+                     options.success(parse_json_stream(data));
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -352,7 +407,7 @@ RucioClient.prototype.did_get_rules = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
@@ -371,7 +426,68 @@ RucioClient.prototype.list_replication_rule = function(options) {
                  },
                  error: function(jqXHR, textStatus, errorThrown)
                  {
-                     options.error(jqXHR, textStatus, errorThrown)
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
+/* get all locks and their states for a rule id */
+RucioClient.prototype.get_replica_lock_for_rule_id = function(options) {
+    var url = this.url + '/rules/' + options.rule_id + '/locks';
+    jQuery.ajax({url: url,
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'text',
+                 success: function(data)
+                 {
+                     options.success(parse_json_stream(data));
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
+/* get request by did */
+RucioClient.prototype.get_request_by_did = function(options) {
+    var url = this.url + '/requests/' + options.scope + '/' + options.name + '/' + options.rse;
+    jQuery.ajax({url: url,
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'json',
+                 success: function(data)
+                 {
+                     options.success(data);
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
+/* get subscription by id */
+RucioClient.prototype.get_subscription_by_id = function(options) {
+    var url = this.url + '/subscriptions/Id/' + options.id;
+    if (options.async == null) {
+        options.async = true;
+    }
+    jQuery.ajax({url: url,
+                 async: options.async,
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'json',
+                 success: function(data)
+                 {
+                     options.success(data);
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
                  }
         });
 };
